@@ -146,5 +146,8 @@ XAUTH_SIGNIN_SUCCESS_URL = '/'
 XAUTH_LOGOUT_URL = '/'
 XAUTH_ACCOUNT_FORM = 'account.forms.SignupForm'
 XAUTH_PROFILE_FIELDS = ['nickname', 'email', 'fullname', 'country']
-XAUTH_OAUTH_TWITTER_CONSUMER_KEY = '2W0gPV3RxSaT5U37EIgIaQ'
-XAUTH_OAUTH_TWITTER_CONSUMER_SECRET = 'XnJ4KqceE8emoV4wvKXbYjGJmfe5aoWdUKCqgDIOM'
+
+try:
+    from settings_local import *
+except ImportError:
+    pass
